@@ -7,15 +7,17 @@ except ImportError, e:
     from django.core.exceptions import ImproperlyConfigured
     raise ImproperlyConfigured("Error loading zxJDBC module: %s" % e)
 
-from django.db.backends import BaseDatabaseFeatures, BaseDatabaseValidation
+from django.db.backends import BaseDatabaseWrapper, BaseDatabaseFeatures, BaseDatabaseValidation
 from django.db.backends import BaseDatabaseOperations
+#from django.db.backends.mysql.base import DatabaseOperations as MysqlDatabaseOperations
 from django.db.backends.mysql.client import DatabaseClient
+#from django.db.backends.mysql.introspection import DatabaseIntrospection
 from doj.backends.zxjdbc.mysql.creation import DatabaseCreation
 
 from doj.backends.zxjdbc.mysql.introspection import DatabaseIntrospection
-from doj.backends.zxjdbc.common import (
-    zxJDBCDatabaseWrapper, zxJDBCOperationsMixin, zxJDBCFeaturesMixin, 
-    zxJDBCCursorWrapper, set_default_isolation_level)
+from doj.backends.zxjdbc.common import zxJDBCOperationsMixin, zxJDBCFeaturesMixin
+from doj.backends.zxjdbc.common import zxJDBCCursorWrapper, set_default_isolation_level
+from doj.backends.zxjdbc.common import zxJDBCDatabaseWrapper
 from com.ziclix.python.sql.handler import MySQLDataHandler
 
 DatabaseError = Database.DatabaseError
@@ -126,9 +128,9 @@ class DatabaseOperations(zxJDBCOperationsMixin, MysqlDatabaseOperations):
 
 
 class DatabaseWrapper(zxJDBCDatabaseWrapper):
-    driver_class_name = "com.mysql.jdbc.Driver"
+    driver_class_name = 'com.mysql.jdbc.Driver'
     jdbc_url_pattern = \
-        "jdbc:mysql://%(DATABASE_HOST)s%(DATABASE_PORT)s/%(DATABASE_NAME)s"
+        "jdbc:mysql://%(HOST)s%(PORT)s/%(NAME)s"
     operators = {
         'exact': '= %s',
         'iexact': 'LIKE %s',
@@ -146,21 +148,22 @@ class DatabaseWrapper(zxJDBCDatabaseWrapper):
         'iendswith': 'LIKE %s',
     }
 
+
     def __init__(self, *args, **kwargs):
         super(DatabaseWrapper, self).__init__(*args, **kwargs)
 
-        self.features = DatabaseFeatures()
+        self.features = DatabaseFeatures(self)
         self.ops = DatabaseOperations()
         self.client = DatabaseClient(self)
         self.creation = DatabaseCreation(self)
         self.introspection = DatabaseIntrospection(self)
-        self.validation = BaseDatabaseValidation()
+        self.validation = BaseDatabaseValidation(self)
 
     def _cursor(self):
         if self.connection is None:
             self.connection = self.new_connection()
             # make transactions transparent to all cursors
-            set_default_isolation_level(self.connection)
+            set_default_isolation_level(self.connection, innodb_binlog=True)
         real_cursor = self.connection.cursor()
         # Use the MySQL DataHandler for better compatibility:
         real_cursor.datahandler = MySQLDataHandler(real_cursor.datahandler)
