@@ -1,3 +1,4 @@
+import sys
 import os
 import shutil
 import tempfile
@@ -23,6 +24,13 @@ class Command(BaseCommand):
                     help='List of python top-level packages (directories) to '
                          'include separated by the "%s" character' %
                           os.path.pathsep),
+        make_option('--include-in-classes', dest='include_in_classes',
+                    default='',
+                    help='List of directories with files that must be '
+                         'included in WEB-INF/classes, separated by the "%s" character. '
+                         'Use this option to include additional resources '
+                         'required by your aplication.' %
+                          os.path.pathsep),
         make_option('--include-py-path-entries', dest='include_py_path_entries',
                     default='',
                     help='List of python path entries (directories or JAR/ZIP '
@@ -33,7 +41,18 @@ class Command(BaseCommand):
                          'unspecified, the project name is used. The context '
                           'root name is used as the name of the WAR file, and '
                           'as a prefix for some url-related settings, such as '
-                          'MEDIA_URL')
+                          'MEDIA_URL'),
+        make_option('--shared-war', action='store_true', dest='shared_war',
+                    help='Do not include Jython, it\'s libraries, django-jython,'
+                         'or Django. Useful for deployment of multiple django '
+                         'projects on a single app server. Note that your '
+                         'application server must be configured to correctly '
+                         'find jython.jar, django-jython, and the Jython and '
+                         'Django libs. '),
+        make_option('--keep-temp-files', action='store_true', dest='keep_temp_files',
+                    help='Do not delete the temporary files with the exploded '
+                         'war file. You can use this feature for debugging '
+                         'purposes.'),
     )
     help = ("Builds a WAR file for stand-alone deployment on a Java "
             "Servlet container")
@@ -43,7 +62,14 @@ class Command(BaseCommand):
         context_root = options['context_root'] or project_name
         temp_dir = tempfile.mkdtemp()
         exploded_war_dir = os.path.join(temp_dir, project_name)
-        print
+        if ('django.contrib.admin' in settings.INSTALLED_APPS) and \
+                (settings.ADMIN_MEDIA_PREFIX == settings.MEDIA_URL):
+            print
+            print "Both ADMIN_MEDIA_PREFIX and MEDIA_URL point to %s" % settings.MEDIA_URL
+            print "This will cause admin media files to override project media files"
+            print "Please change your settings and run the war command again"
+            print
+            sys.exit(1)
         print "Assembling WAR on %s" % exploded_war_dir
         print
         self.copy_skel(exploded_war_dir)
@@ -51,16 +77,26 @@ class Command(BaseCommand):
                             ['WEB-INF/web.xml', 'application.py'],
                             {'project_name': project_name,
                              'settings': settings})
-        self.copy_jython(exploded_war_dir)
-        self.copy_django(exploded_war_dir)
-        self.copy_admin_media(exploded_war_dir)
+        if not options['shared_war']:
+            self.copy_jython(exploded_war_dir)
+            self.copy_django(exploded_war_dir)
         self.copy_project(exploded_war_dir)
         self.fix_project_settings(exploded_war_dir, context_root)
         self.copy_project_media(exploded_war_dir)
-        self.copy_apps(exploded_war_dir)
+        self.copy_admin_media(exploded_war_dir)
+        if not options['shared_war']:
+            self.copy_apps(exploded_war_dir, settings.INSTALLED_APPS)
+        else:
+            self.copy_apps(exploded_war_dir, 
+                           [app for app in settings.INSTALLED_APPS if app != "doj"])
         if options['include_java_libs']:
             for java_lib in options['include_java_libs'].split(os.path.pathsep):
                 self.copy_java_jar(exploded_war_dir, java_lib)
+        if options['include_in_classes']:
+            include_in_classes = options['include_in_classes'].split(
+                os.path.pathsep)
+            for data_dir in include_in_classes:
+                self.copy_to_classes(exploded_war_dir, data_dir)
         if options['include_py_packages']:
             py_package_dirs = options['include_py_packages'].split(
                 os.path.pathsep)
@@ -83,8 +119,9 @@ class Command(BaseCommand):
         war_file_name = os.path.join(self.project_directory(),
                                      '..', context_root + '.war')
         self.war(exploded_war_dir, war_file_name)
-        print "Cleaning %s..." % temp_dir
-        shutil.rmtree(temp_dir)
+        if not options['keep_temp_files']:
+            print "Cleaning %s..." % temp_dir
+            shutil.rmtree(temp_dir)
         print """
 Finished.
 
@@ -107,9 +144,12 @@ Now you can copy %s to whatever location your application server wants it.
             f.write(template.render(Context(vars)))
             f.close()
 
-    def copy_jython(self, exploded_war_dir):
+    def get_jython_home(self):
         jython_lib_path = os.path.dirname(os.path.abspath(os.__file__))
-        jython_home = os.path.dirname(jython_lib_path)
+        return os.path.dirname(jython_lib_path), jython_lib_path
+
+    def copy_jython(self, exploded_war_dir):
+        jython_home, jython_lib_path = self.get_jython_home()
         if jython_home.endswith('.jar'):
             # We are on a Jython stand-alone installation.
             self.copy_java_jar(exploded_war_dir, jython_home)
@@ -128,13 +168,28 @@ Now you can copy %s to whatever location your application server wants it.
                                                   'javalib', '*.jar')):
                     self.copy_java_jar(exploded_war_dir, jar)
             self.copy_py_path_entry(exploded_war_dir, jython_lib_path)
+            # create_site_packages_pth():
+            site_packages_pth = os.path.join(exploded_war_dir,
+                                    'WEB-INF', 'lib-python', 'site-packages.pth')
+            pth_file = file(site_packages_pth, 'w')
+            libdir_name = os.path.basename(jython_lib_path)
+            site_packages_rel_path = os.path.join(libdir_name, 'site-packages')
+            pth_file.write("%s\n" % site_packages_rel_path)
+            for egg in glob.glob(os.path.join(jython_lib_path, 'site-packages', '*.egg')):
+                pth_file.write("%s\n" % os.path.join(site_packages_rel_path, os.path.basename(egg)))
+            pth_file.close()
 
     def copy_django(self, exploded_war_dir):
         import django
         django_dir = os.path.dirname(os.path.abspath(django.__file__))
-        self.copy_py_package_dir(exploded_war_dir, django_dir)
+        jython_home, jython_lib_path = self.get_jython_home()
+        if not django_dir.startswith(jython_lib_path):
+            self.copy_py_package_dir(exploded_war_dir, django_dir)
 
     def copy_admin_media(self, exploded_war_dir):
+        if 'django.contrib.admin' not in settings.INSTALLED_APPS:
+            print "Skipping admin media: django.contrib.admin not in INSTALLED_APPS"
+            return
         from django.contrib import admin
         self.copy_media(exploded_war_dir,
                         os.path.join(os.path.dirname(admin.__file__), 'media'),
@@ -199,15 +254,17 @@ deployed settings file. You can append the following block at the end of the fil
                         settings.MEDIA_ROOT,
                         os.path.join(*settings.MEDIA_URL.split('/')))
 
-    def copy_apps(self, exploded_war_dir):
+    def copy_apps(self, exploded_war_dir, apps):
         already_included_pkgs = ['django', self.project_name()]
-        for app in settings.INSTALLED_APPS:
+        for app in apps:
             # We copy the whole package in which the app resides
             app_pkg = __import__(app)
             if app_pkg.__name__ in already_included_pkgs:
                 continue
             app_pkg_dir = os.path.dirname(os.path.abspath(app_pkg.__file__))
-            self.copy_py_package_dir(exploded_war_dir, app_pkg_dir)
+            jython_home, jython_lib_path = self.get_jython_home()
+            if not app_pkg_dir.startswith(jython_lib_path):
+                self.copy_py_package_dir(exploded_war_dir, app_pkg_dir)
             already_included_pkgs.append(app_pkg.__name__)
 
     def copy_java_jar(self, exploded_war_dir, java_lib):
@@ -218,6 +275,15 @@ deployed settings file. You can append the following block at the end of the fil
                     os.path.join(exploded_war_dir,
                                  'WEB-INF', 'lib', dest_name))
 
+    def copy_to_classes(self, exploded_war_dir, data_dir):
+        """
+        Copies files from a directory to classes/
+        """
+        print "Copying files from %s to WEB-INF/classes..." % data_dir
+        shutil.copytree(data_dir,
+                        os.path.join(exploded_war_dir,
+                                     'WEB-INF', 'classes'))
+
     def copy_py_package_dir(self, exploded_war_dir, py_package_dir):
         """
         Copies a directory containing a python package to lib-python/
@@ -251,10 +317,30 @@ deployed settings file. You can append the following block at the end of the fil
             d = exploded_war_dir
             for sub_dir in os.path.split(dest_relative_path)[:-1]:
                 d = os.path.join(d, sub_dir)
-                os.mkdir(d)
+                if not os.path.exists(d):
+                    os.mkdir(d)
         print "Copying %s..." % dest_relative_path
         shutil.copytree(src_dir,
                         os.path.join(exploded_war_dir, dest_relative_path))
+        # check if media src_dir is within project folder, then remove
+        # duplicates from war
+        project_dir = self.project_directory()
+        jython_home, jython_lib_path = self.get_jython_home()
+        dupe_root = None
+        if src_dir.startswith(project_dir):
+            dupe_root = project_dir
+            dest_dir = self.project_name()
+        elif src_dir.startswith(jython_lib_path):
+            dupe_root = jython_lib_path             
+            dest_dir = os.path.basename(jython_lib_path)            
+        if dupe_root:
+            # get the relative path of original media in packed war and remove
+            src_rel_dir = src_dir[len(dupe_root) + 1:]
+            print(" - source: %s" % src_dir)
+            duplicate_media = os.path.join(exploded_war_dir, "WEB-INF", 
+                "lib-python", dest_dir, src_rel_dir)
+            print("Removing duplicate media: %s" % duplicate_media)
+            shutil.rmtree(os.path.join(duplicate_media))
 
     def war(self, exploded_war_dir, war_file_name):
         # Make sure we are working with absolute paths
